@@ -1,5 +1,5 @@
 /*
- * Copyright 2000-2001 Misha Nasledov <misha@nasledov.com>
+ * Copyright (C) 2000-2002 Misha Nasledov <misha@nasledov.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
@@ -39,6 +39,7 @@
 #include "files.h"
 #include "network.h"
 #include "news15.h"
+#include "log.h"
 
 time_t start_time;
 time_t total_time;
@@ -294,11 +295,20 @@ static void changed_font (session *sess)
 	}
 }
 
+#if 0 /* XXX */
+static void changed_logging (session *sess)
+{
+	if(!gtkhx_prefs.logging) {
+		close_logs();
+	}
+}
+#endif
+
 static void changed_downloadpath (session *sess)
 {
 	if (!*gtkhx_prefs.download_path)
 	{
-		g_free (gtkhx_prefs.download_path);
+/*		g_free (gtkhx_prefs.download_path); */
 		gtkhx_prefs.download_path = g_strdup(".");
 	}
 }
@@ -380,6 +390,9 @@ struct cfgvar
 #endif
 	{"ICON", {&sessions[0].htlc.icon}, UINT16, 0, /*changed_nickoricon*/NULL, NULL},
 	{"ICONS", {&gtkhx_prefs.icon_str}, STRING, 0, parse_icons, NULL},
+#if 0 /* XXX */
+	{"LOGGING", {&gtkhx_prefs.logging}, BOOLEAN, 0, changed_logging, NULL},
+#endif 
 	{"NEWSXPOS", {&gtkhx_prefs.geo.news.xpos}, INT, 0, NULL, NULL},
 	{"NEWSXSIZE", {&gtkhx_prefs.geo.news.xsize}, INT, 0, NULL, NULL},
 	{"NEWSYPOS", {&gtkhx_prefs.geo.news.ypos}, INT, 0, NULL, NULL},
@@ -445,6 +458,9 @@ enum
 	GREEN_IDX,
 	ICON_IDX,
 	ICONS_IDX,
+#if 0 /* XXX */
+	LOGGING_IDX,
+#endif
 	NEWSXPOS_IDX,
 	NEWSXSIZE_IDX,
 	NEWSYPOS_IDX,
@@ -1149,6 +1165,27 @@ static void settings_page_files(GtkWidget *vbox)
 	gtk_box_pack_start(GTK_BOX(wid), table, 0, 0, 0);
 }
 
+#if 0 /* XXX */
+static void settings_page_logging (GtkWidget *vbox)
+{
+	GtkWidget *wid;
+	GtkWidget *table;
+
+	wid = settings_create_group(vbox, _("Logging"));
+	table = gtk_table_new(1, 1, 0);
+
+	cfgvars[LOGGING_IDX].widget = gtk_check_button_new_with_label(
+		_("Log Chats/Private Messages"));
+	gtk_toggle_button_set_active((GtkToggleButton*)cfgvars[LOGGING_IDX].widget,
+								 gtkhx_prefs.logging);
+
+	gtk_table_attach(GTK_TABLE(table), cfgvars[LOGGING_IDX].widget, 0,
+										1, 0, 1, GTK_EXPAND|GTK_FILL, 0, 0, 0);
+
+
+	gtk_box_pack_start(GTK_BOX(wid), table, 0, 0, 0);
+}
+#endif
 
 static void settings_page_sound(GtkWidget *vbox)
 {
@@ -1748,6 +1785,12 @@ void create_options_window(GtkWidget *widget, gpointer data)
 								_("Threaded News"), last_top, &last_child,
 								page_index++, settings_page_news15);
 
+#if 0 /* XXX */
+	vbox = settings_create_page(book, _("Logging Settings"), ctree,
+								_("Logging Settings"), last_top, &last_child,
+								page_index++, settings_page_logging);
+#endif
+
 	vbox = settings_create_page(book, _("Miscellaeneous"), ctree,
 								_("Miscellaeneous"), last_top, &last_child,
 								page_index++, settings_page_misc);
