@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2001 Misha Nasledov <misha@nasledov.com>
+ * Copyright (C) 2000-2002 Misha Nasledov <misha@nasledov.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by the
@@ -224,14 +224,19 @@ void hx_rcv_news_post (struct htlc_conn *htlc)
 	dh_start(htlc) {
 		if (_type != HTLS_DATA_NEWS)
 			continue;
+
 		news_len += _len;
 		news_buf = g_realloc(news_buf, news_len + 1);
+
 		memmove(&(news_buf[_len]), news_buf, news_len - _len);
 		memcpy(news_buf, dh->data, _len);
+
 		CR2LF(news_buf, _len);
 		strip_ansi(news_buf, _len);
-		news_buf[news_len] = 0;
+		news_buf[news_len] = '\0';
+
 		hx_output.news_post(htlc, news_buf, _len);
+
 		play_sound(NEWS_POST);
 	} dh_end();
 }
@@ -264,8 +269,8 @@ void hx_rcv_task (struct htlc_conn *htlc)
 
 void hx_rcv_user_change (struct htlc_conn *htlc)
 {
-	guint32 cid = 0, icon = 0, color = 0;
-	guint16 nlen = 0, got_color = 0, uid = 0;
+	guint32 cid = 0;
+	guint16 nlen = 0, got_color = 0, uid = 0, color = 0, icon = 0;
 	guint8 name[32];
 	struct chat *chat;
 	struct hx_user *user;
